==> 3.4.1.tar.gz: xbackbone/resources/lang/es.lang.php <==
<?php
return [
    'lang' => 'Español',
    'yes' => 'Sí',
    'no' => 'No',
    'send' => 'Enviar',
    'no_media' => 'Contenido no encontrado.',
    'login.username' => 'Nombre de usuario o correo electrónico',
    'password' => 'Contraseña',
    'login' => 'Iniciar sesión',
    'username' => 'Nombre de usuario',
    'home' => 'Inicio',
    'users' => 'Usuarios',
    'system' => 'Sistema',
    'profile' => 'Perfil',
    'logout' => 'Cerrar sesión',
    'pager.next' => 'Siguiente',
    'pager.previous' => 'Previo',
    'copy_link' => 'Copiar enlace',
    'public.telegram' => 'Compartir en Telegram',
    'public.delete_text' => '¿Está seguro que desea borrar este elemento? ¡Será borrado para siempre!',
    'preview' => 'Vista previa',
    'filename' => 'Nombre del archivo',
    'size' => 'Tamaño',
    'public' => 'Público',
    'owner' => 'Dueño',
    'date' => 'Fecha',
    'raw' => 'Mostrar archivo sin formato',
    'download' => 'Descargar',
    'delete' => 'Borrar',
    'publish' => 'Publicar',
    'hide' => 'Esconder',
    'files' => 'Archivos',
    'orphaned_files' => 'Archivos huérfanos',
    'theme' => 'Tema',
    'click_to_load' => 'Clic para cargar…',
    'apply' => 'Aplicar',
    'save' => 'Guardar',
    'used' => 'Usado',
    'system_info' => 'Información del Sistema',
    'user.create' => 'Crear Usuario',
    'user.edit' => 'Editar Usuario',
    'is_active' => 'Es activo',
    'is_admin' => 'Es administrador',
    'your_profile' => 'Tu Perfil',
    'token' => 'Ficha',
    'copy' => 'Copiar',
    'update' => 'Actualizar',
    'edit' => 'Editar',
    'client_config' => 'Configuración del Cliente',
    'user_code' => 'Código de Usuario',
    'active' => 'Activo',
    'admin' => 'Administrador',
    'reg_date' => 'Fecha de Registración',
    'none' => 'Ninguno',
    'open' => 'Abrir',
    'confirm' => 'Confirmación',
    'confirm_string' => '¿Está seguro?',
    'installed' => '¡Instalación completa!',
    'bad_login' => 'Credenciales incorrectas.',
    'account_disabled' => 'Su cuenta está desactivada.',
    'welcome' => '¡Bienvenido, %s!',
    'goodbye' => '¡Adiós!',
    'token_not_found' => 'Ficha indicada No encontrada.',
    'email_required' => 'El correo electrónico es requisito.',
    'email_taken' => 'El correo electrónico ya está en uso.',
    'username_required' => 'El Nombre de Usuario es requisito.',
    'username_taken' => 'El Nombre de Usuario ya está en uso.',
    'password_required' => 'La Contraseña es requisito.',
    'user_created' => '¡Usuario «%s» creado!',
    'user_updated' => '¡Usuario «%s» actualizado!',
    'profile_updated' => '¡Perfil actualizado con éxito!',
    'user_deleted' => 'Usuario borrado.',
    'cannot_delete' => 'No puede borrarse a usted mismo.',
    'cannot_write_file' => 'La ruta de destino no se puede escribir.',
    'deleted_orphans' => 'Borró los archivos huérfanos %d con éxito.',
    'switch_to' => 'Cambiar a',
    'gallery' => 'Galería',
    'table' => 'Tabla',
    'dotted_search' => 'Búsqueda…',
    'order_by' => 'Ordenar por…',
    'time' => 'Tiempo',
    'name' => 'Nombre',
    'maintenance' => 'Mantenimiento',
    'path_not_writable' => 'La ruta de salida no se puede escribir.',
    'already_latest_version' => 'Ya tiene la última versión.',
    'new_version_available' => '¡Nueva versión %s disponible!',
    'cannot_retrieve_file' => 'No se puede recuperar el archivo.',
    'file_size_no_match' => 'El archivo descargado no coincide con el tamaño de archivo correcto.',
    'check_for_updates' => 'Buscar actualizaciones',
    'upgrade' => 'Mejorar',
    'updates' => 'Actualizaciones',
    'maintenance_in_progress' => 'Plataforma en mantenimiento, inténtelo más tarde…',
    'cancel' => 'Cancelar',
    'enforce_language' => 'Afirmar lenguaje',
    'auto_set' => 'Establecer automáticamente',
    'translated_strings' => 'cadenas de texto traducidas',
    'total_strings' => 'total de cadenas de texto',
    'lang_name' => 'nombre del lenguaje',
    'default_lang_behavior' => 'XBackBone tratará de coincidir con el lenguaje predeterminado del navegador (recurrimos al Inglés automáticamente).',
    'lang_set' => 'Lenguaje del sistema impuesto a "%s"',
    'upload' => 'Subir',
    'delete_all' => 'Borrar Todo',
    'danger_zone' => 'Zona De Peligro',
    'recaptcha_failed' => 'reCAPTCHA Falló',
    'php_info' => 'Información PHP',
    'system_settings' => 'Configuracion de Systema',
    'mail.new_account' => '% s – Creación de nueva cuenta',
    'send_notification' => 'Enviar notificación por correo electrónico',
    'mail.recover_password' => '% s – Recuperación de contraseña',
    'mail.activate_account' => '%s – Activación de la cuenta',
    'register_success' => 'La cuenta ha sido creada, se ha enviado un correo electrónico de confirmación.',
    'donate_text' => 'Si te gusta XBackBone, considera una donación para apoyar el desarrollo!',
    'donation' => 'Donación',
    'drop_to_upload' => 'Haz clic o arrastra tus archivos aquí para subirlos.',
    'no_upload_token' => 'No tienes una clave personal de carga. (Genera uno e inténtalo de nuevo.)',
    'prerelease_channel' => 'Canal de prelanzamiento',
    'clean_orphaned_uploads' => 'Limpiar las cargas de los huéspedes',
    'cannot_demote' => 'No puedes degradarte.',
    'copied' => '¡Copiado en el portapapeles!',
    'quota_recalculated' => 'Cuota de usuario recalculada desde el disco con éxito.',
    'recalculate_user_quota' => 'Recalcular la cuota de usuarios desde el disco',
    'quota_enabled' => 'Activar la cuota de usuarios',
    'show_changelog' => 'Mostrar el registro de cambios',
    'changelog' => 'Registro de cambios',
    'zip_ext_not_loaded' => 'La extensión zip requerida no está cargada',
    'auto_tagging' => 'Carga automática de etiquetas',
    'no_tags' => 'No se han añadido etiquetas',
    'upload_max_file_size' => 'El tamaño máximo del archivo es actualmente %s.',
    'ldap_cant_connect' => 'No se puede conectar con el servidor de autentificación LDAP.',
    'user_create_password' => 'Si se deja vacío, es posible que desee enviar una notificación a la dirección de correo electrónico del usuario.',
    'mail.new_account_text_with_pw' => 'Hola %s!<br>se ha creado una nueva cuenta para ti en %s (<a href="%s">%s</a>), haz clic en el siguiente enlace para establecer una contraseña y activarla:<br><br><a href="%s">%s</a>',
    'mail.new_account_text_with_reset' => 'Hola %s!<br>se ha creado una nueva cuenta para ti en %s (<a href="%s">%s</a>), haz clic en el siguiente enlace para establecer una contraseña y activarla:<br><br><a href="%s">%s</a>',
    'recaptcha_enabled' => 'reCAPTCHA activado',
    'account_media_deleted' => 'Se han eliminado todos los archivos de la cuenta.',
    'clear_account' => 'Limpiar cuenta',
    'delete_selected' => 'Eliminar seleccionado',
    'used_space' => 'Espacio usado',
    'password_restored' => 'Restablecimiento de la contraseña.',
    'password_match' => 'La contraseña y la contraseña repetida deben ser las mismas.',
    'password_repeat' => 'Repite la contraseñá',
    'account_activated' => 'Cuenta activada, ¡ahora puedes iniciar sesión!',
    'recover_email_sent' => 'Si está presente, se ha enviado un correo electrónico de recuperación a la cuenta especificada.',
    'mail.recover_text' => 'Hola %s,<br>se ha solicitado el restablecimiento de la contraseña de su cuenta. Para completar el procedimiento haga clic en el siguiente enlace:<br><br><a href="%s">%s</a><br>Si no fue usted quien solicitó el restablecimiento de la contraseña, simplemente ignore este correo electrónico.',
    'mail.activate_text' => 'Hola %s!<br>gracias por crear tu cuenta en %s (<a href="%s">%s</a>), haz clic en el siguiente enlace para activarla:<br><br><a href="%s">%s</a>',
    'invalid_quota' => 'Valores no válidos como cuota de usuario por defecto.',
    'max_user_quota' => 'Cuota máxima del  usuario',
    'default_user_quota' => 'Cuota de usuarios por defecto',
    'register' => 'Registrarse',
    'no_account' => '¿No tienes cuenta?',
    'password_recovery' => 'Recuperar contraseña',
    'export_data' => 'Exportar datos',
    'settings_saved' => '¡Configuración del sistema guardada!',
    'copy_url_behavior' => 'Modo copiar URL',
    'hide_by_default' => 'Ocultar media por defecto',
    'register_enabled' => 'Registros abiertos',
    'dont_close' => 'No cierres esta pestaña hasta que se haya completado.',
    'please_wait' => 'Por favor, espera…',
    'remember_me' => 'Recuerdame',
    'custom_head_html_hint' => 'Este contenido se añadirá en la etiqueta <head> de cada página.',
    'custom_head_html' => 'Contenido personalizado del encabezado HTML',
];

==> 3.6.3.tar.gz: xbackbone/resources/lang/es.lang.php <==
<?php
return [
    'lang' => 'Español',
    'yes' => 'Sí',
    'no' => 'No',
    'send' => 'Enviar',
    'no_media' => 'Contenido no encontrado.',
    'login.username' => 'Nombre de usuario o correo electrónico',
    'password' => 'Contraseña',
    'login' => 'Iniciar sesión',
    'username' => 'Nombre de usuario',
    'home' => 'Inicio',
    'users' => 'Usuarios',
    'system' => 'Sistema',
    'profile' => 'Perfil',
    'logout' => 'Cerrar sesión',
    'pager.next' => 'Siguiente',
    'pager.previous' => 'Previo',
    'copy_link' => 'Copiar enlace',
    'public.telegram' => 'Compartir en Telegram',
    'public.delete_text' => '¿Está seguro que desea borrar este elemento? No vas a poder recuperarlo',
    'preview' => 'Vista previa',
    'filename' => 'Nombre del archivo',
    'size' => 'Tamaño',
    'public' => 'Público',
    'owner' => 'Dueño',
    'date' => 'Fecha',
    'raw' => 'Mostrar archivo sin formato',
    'download' => 'Descargar',
    'delete' => 'Borrar',
    'publish' => 'Publicar',
    'hide' => 'Esconder',
    'files' => 'Archivos',
    'orphaned_files' => 'Archivos huérfanos',
    'theme' => 'Tema',
    'click_to_load' => 'Clic para cargar…',
    'apply' => 'Aplicar',
    'save' => 'Guardar',
    'used' => 'Usado',
    'system_info' => 'Información del Sistema',
    'user.create' => 'Crear Usuario',
    'user.edit' => 'Editar Usuario',
    'is_active' => 'Es activo',
    'is_admin' => 'Es administrador',
    'your_profile' => 'Tu Perfil',
    'token' => 'Ficha',
    'copy' => 'Copiar',
    'update' => 'Actualizar',
    'edit' => 'Editar',
    'client_config' => 'Configuración del Cliente',
    'user_code' => 'Código de Usuario',
    'active' => 'Activo',
    'admin' => 'Administrador',
    'reg_date' => 'Fecha de Registración',
    'none' => 'Ninguno',
    'open' => 'Abrir',
    'confirm' => 'Confirmación',
    'confirm_string' => '¿Está seguro?',
    'installed' => '¡Instalación completa!',
    'bad_login' => 'Credenciales incorrectas.',
    'account_disabled' => 'Su cuenta está desactivada.',
    'welcome' => '¡Bienvenido, %s!',
    'goodbye' => '¡Adiós!',
    'token_not_found' => 'Ficha indicada No encontrada.',
    'email_required' => 'El correo electrónico es requisito.',
    'email_taken' => 'El correo electrónico ya está en uso.',
    'username_required' => 'El Nombre de Usuario es requisito.',
    'username_taken' => 'El Nombre de Usuario ya está en uso.',
    'password_required' => 'La Contraseña es requisito.',
    'user_created' => '¡Usuario «%s» creado!',
    'user_updated' => '¡Usuario «%s» actualizado!',
    'profile_updated' => '¡Perfil actualizado con éxito!',
    'user_deleted' => 'Usuario borrado.',
    'cannot_delete' => 'No puede borrarse a usted mismo.',
    'cannot_write_file' => 'La ruta de destino no se puede escribir.',
    'deleted_orphans' => 'Borró los archivos huérfanos %d con éxito.',
    'switch_to' => 'Cambiar a',
    'gallery' => 'Galería',
    'table' => 'Tabla',
    'dotted_search' => 'Búsqueda…',
    'order_by' => 'Ordenar por…',
    'time' => 'Tiempo',
    'name' => 'Nombre',
    'maintenance' => 'Mantenimiento',
    'path_not_writable' => 'La ruta de salida no se puede escribir.',
    'already_latest_version' => 'Ya tiene la última versión.',
    'new_version_available' => '¡Nueva versión %s disponible!',
    'cannot_retrieve_file' => 'No se puede recuperar el archivo.',
    'file_size_no_match' => 'El archivo descargado no coincide con el tamaño de archivo correcto.',
    'check_for_updates' => 'Buscar actualizaciones',
    'upgrade' => 'Mejorar',
    'updates' => 'Actualizaciones',
    'maintenance_in_progress' => 'Plataforma en mantenimiento, inténtelo más tarde…',
    'cancel' => 'Cancelar',
    'enforce_language' => 'Afirmar lenguaje',
    'auto_set' => 'Establecer automáticamente',
    'translated_strings' => 'cadenas de texto traducidas',
    'total_strings' => 'total de cadenas de texto',
    'lang_name' => 'nombre del lenguaje',
    'default_lang_behavior' => 'XBackBone tratará de coincidir con el lenguaje predeterminado del navegador (recurrimos al Inglés automáticamente).',
    'lang_set' => 'Lenguaje del sistema impuesto a "%s"',
    'upload' => 'Subir',
    'delete_all' => 'Borrar Todo',
    'danger_zone' => 'Zona De Peligro',
    'recaptcha_failed' => 'reCAPTCHA Falló',
    'php_info' => 'Información PHP',
    'system_settings' => 'Configuracion de Systema',
    'mail.new_account' => '% s – Creación de nueva cuenta',
    'send_notification' => 'Enviar notificación por correo electrónico',
    'mail.recover_password' => '% s – Recuperación de contraseña',
    'mail.activate_account' => '%s – Activación de la cuenta',
    'register_success' => 'La cuenta ha sido creada, se ha enviado un correo electrónico de confirmación.',
    'donate_text' => 'Si te gusta XBackBone, considera una donación para apoyar el desarrollo!',
    'donation' => 'Donación',
    'drop_to_upload' => 'Haz clic o arrastra tus archivos aquí para subirlos.',
    'no_upload_token' => 'No tienes una clave personal de carga. (Genera uno e inténtalo de nuevo.)',
    'prerelease_channel' => 'Canal de prelanzamiento',
    'clean_orphaned_uploads' => 'Limpiar las cargas de los huéspedes',
    'cannot_demote' => 'No puedes degradarte.',
    'copied' => '¡Copiado en el portapapeles!',
    'quota_recalculated' => 'Cuota de usuario recalculada desde el disco con éxito.',
    'recalculate_user_quota' => 'Recalcular la cuota de usuarios desde el disco',
    'quota_enabled' => 'Activar la cuota de usuarios',
    'show_changelog' => 'Mostrar el registro de cambios',
    'changelog' => 'Registro de cambios',
    'zip_ext_not_loaded' => 'La extensión zip requerida no está cargada',
    'auto_tagging' => 'Carga automática de etiquetas',
    'no_tags' => 'No se han añadido etiquetas',
    'upload_max_file_size' => 'El tamaño máximo del archivo es actualmente %s.',
    'ldap_cant_connect' => 'No se puede conectar con el servidor de autentificación LDAP.',
    'user_create_password' => 'Si se deja vacío, es posible que desee enviar una notificación a la dirección de correo electrónico del usuario.',
    'mail.new_account_text_with_pw' => 'Hola %s!<br>se ha creado una nueva cuenta para ti en %s (<a href="%s">%s</a>), haz clic en el siguiente enlace para establecer una contraseña y activarla:<br><br><a href="%s">%s</a>',
    'mail.new_account_text_with_reset' => 'Hola %s!<br>se ha creado una nueva cuenta para ti en %s (<a href="%s">%s</a>), haz clic en el siguiente enlace para establecer una contraseña y activarla:<br><br><a href="%s">%s</a>',
    'recaptcha_enabled' => 'reCAPTCHA activado',
    'account_media_deleted' => 'Se han eliminado todos los archivos de la cuenta.',
    'clear_account' => 'Limpiar cuenta',
    'delete_selected' => 'Eliminar seleccionado',
    'used_space' => 'Espacio usado',
    'password_restored' => 'Restablecimiento de la contraseña.',
    'password_match' => 'La contraseña y la contraseña repetida deben ser las mismas.',
    'password_repeat' => 'Repite la contraseñá',
    'account_activated' => 'Cuenta activada, ¡ahora puedes iniciar sesión!',
    'recover_email_sent' => 'Si está presente, se ha enviado un correo electrónico de recuperación a la cuenta especificada.',
    'mail.recover_text' => 'Hola %s,<br>se ha solicitado el restablecimiento de la contraseña de su cuenta. Para completar el procedimiento haga clic en el siguiente enlace:<br><br><a href="%s">%s</a><br>Si no fue usted quien solicitó el restablecimiento de la contraseña, simplemente ignore este correo electrónico.',
    'mail.activate_text' => 'Hola %s!<br>gracias por crear tu cuenta en %s (<a href="%s">%s</a>), haz clic en el siguiente enlace para activarla:<br><br><a href="%s">%s</a>',
    'invalid_quota' => 'Valores no válidos como cuota de usuario por defecto.',
    'max_user_quota' => 'Cuota máxima del usuario',
    'default_user_quota' => 'Cuota de usuarios por defecto',
    'register' => 'Registrarse',
    'no_account' => '¿No tienes cuenta?',
    'password_recovery' => 'Recuperar contraseña',
    'export_data' => 'Exportar datos',
    'settings_saved' => '¡Configuración del sistema guardada!',
    'copy_url_behavior' => 'Modo copiar URL',
    'hide_by_default' => 'Ocultar media por defecto',
    'register_enabled' => 'Registros abiertos',
    'dont_close' => 'No cierres esta pestaña hasta que se haya completado.',
    'please_wait' => 'Por favor, espera…',
    'remember_me' => 'Recuerdame',
    'custom_head_html_hint' => 'Este contenido se añadirá en la etiqueta <head> de cada página.',
    'custom_head_html' => 'Contenido personalizado del encabezado HTML',
    'image_embeds' => 'Incrustar imágenes',
    'recaptcha_keys_required' => 'Todas las claves reCAPTCHA son requeridas.',
    'recaptcha_secret_key' => 'Clave secreta de reCAPTCHA',
    'recaptcha_site_key' => 'Clave del sitio reCAPTCHA',
    'only_recaptcha_v3' => 'Solo reCAPTCHA v3 está soportado.',
    'custom_head_set' => 'Cabecera HTML personalizada aplicada.',
];
